@@ -1,17 +1,19 @@
+import subprocess
 import time
 
-from taskw import TaskWarriorShellout
-
 
 def main(*args):
     config_path = args[0]
 
-    warrior = TaskWarriorShellout(
-        config_filename=config_path
-    )
-
     started = time.time()
-    warrior.sync()
+    subprocess.call(
+        [
+            'task',
+            'rc:%s' % config_path,
+            'sync',
+        ],
+        shell=True,
+    )
     finished = time.time()
 
     total_duration = finished - started
